@@ -224,16 +224,13 @@ def find_causes(data, test_function='default', alpha=0.01):
                 cond_set = list(remain_causes)
                 cond_set.remove(can)
                 for cond in combinations(cond_set, l):
-                    if factor:
-                        data_delete = data[(data[[can] + list(cond)] > -1).all(1)].to_numpy()
-                    else:
-                        data_delete = data.dropna(subset=[can] + list(cond))
-                    cols = np.asarray(
-                        [data_delete.shape[1] - 1] + [varnames.index(can)] + [varnames.index(x) for x in cond])
-                    p_value = globals()[test_function](data_delete, cols)
-                    if p_value > alpha:
-                        causes[var].remove(can)
-                        break
+                    if data_delete.shape[0] > 0:
+                        cols = np.asarray(
+                            [data_delete.shape[1] - 1] + [varnames.index(can)] + [varnames.index(x) for x in cond])
+                        p_value = globals()[test_function](data_delete, cols)
+                        if p_value > alpha:
+                            causes[var].remove(can)
+                            break
             l += 1
     data.pop('missing')
     return causes
